==> UnderB-1.04.tar.gz: UnderB-1.04/c_msg.c <==
#include "c_msg.h"

static char buf[MAX_MSG_LEN+2];
static int last_index = -1;
static int last_lang = -1;

typedef struct {
	char e_msg[MAX_MSG_LEN+1];
	char k_msg[MAX_MSG_LEN+1];
} msg_t;

msg_t msg[N_MSG] = {
	{"--MORE--", "----" },
	{"In progress...", "ѷ~  Ҳ..."},
	{"Done!", " !"},
	{"Cancelled!", "߾!"},
	{"Added.", "߽ϴ."},
	{"Deleting.", "ϴ."},
	{"Deleted.", "."},
	{"Changed.", "ٲϴ."},
	{"Press any key to start.", "غϽð ƹŰ ġø մϴ."},
	{"Done! Press any key.", "ϴ. ƹŰ ġ."},
	{"File uploaded!", "ȭ Ǿϴ!"},
	{"File downloaded", "ȭ ٿε Ǿϴ."},
	{"Sent!", "½ϴ!"},
	{"Edit Talk Override List.", "ũ ܸƮ ."},
	{"Edit Board Manager List.", "  ."},
	{"Sending to:", ":"},
	{"Delete Range:", ":"},
	{"Posting..", " øϴ.."},
	{"FTP Posting (Cntrl-C to cancel)", "FTP  (ּ=Cntrl-C)"},
	{"Posted!", " ÷Ƚϴ!"},
	{"[RETURN to Re: current title]", "[() (Re: )]"},
	{"File edited", " "},
	{"Kicked!", "á!"},
	{"(New Mail)", "(Ծ}"},
	{"[Monitor Mode]     Press CTRL-C or CTRL-D to exit", "[ϳ?] ߴϽ÷ Ʈ-/Ʈ- ġ"},
	{"Enter the letter/number to toggle, RETURN when done", "ٲٰ   ڳ ڸ .   ġ"},
	{"Never logged in", "ѹ   "},
	{"No plan", "ȹ "},
	{"File saved", "ȭ  Ǿ"},
	{"Scanning The Unzapped Boards ...", " 忡  ã Դϴ..."},
	{"Quitting...", "׸ ߴմϴ..."},
	{"* No Board Selected *", "*    *"},

	{"Nothing!", "Գ..ƹ͵ ..."},
	{"Failed.", "߾."},
	{"Must have a name.", "̸ ־."},
	{"Board already exists.", " ѹ ʾ..̹ ־~"},
	{"I don't have that.", " ϱ ׷ ."},
	{"Invalid name", "..װ .."},
	{"Nothing selected.", "  ־ Ұ Ƴ..ϱ.."},
	{"Error connecting!", " !"},
	{"Protocol error; try another?", " . ٽұ?"},
	{"File error!", "ȭ Դϴ!"},
	{"Cannot get account record.", "īƮ    ׿."},
	{"Invalid address!", "ּҺҸ!"},
	{"Zero length file.", "ֺ  峭ġ??"},
	{"Mail could not be delivered to:", " ȵǳ׿."},
	{"Invalid range!", " ȹٷ ־!"},
	{"Permission error!", "۹̼ !"},
	{"Edit failure", " "},
	{"User no longer logged in.", "̹ ."},
	{"User's pager is off", " ׿."},
	{"Refused!", " ߾!"},
	{"User cannot be paged at this time", "   ؿ."},
	{"No answer, Ringing party again", " ׿. ٽ θϴ"},
	{"No longer being paged", "θ  ߳."},
	{"No more memory", "!! ޸ !"},
	{"Terminal type error!", "͹̳ Ÿ !"},
	{"Exec failed!", "ȭ µ  ߾!"},
	{"Unknown error.", ".. !"}
};

void c_msg(int index, int eol)
{
	extern int lang;

	if (index < 0 || index >= N_MSG)
		index = ERR_UNKNOWN;
	if (last_index == -1 || last_index != index ||
		last_lang == -1 || last_lang != lang)
	{
		if (lang)
		{
			if (eol)
				sprintf(buf, "%s\n", msg[index].k_msg);
			else
				strcpy(buf, msg[index].k_msg);
		}
		else
		{
			if (eol)
				sprintf(buf, "%s\n", msg[index].e_msg);
			else
				strcpy(buf, msg[index].e_msg);
		}
		last_index = index;
		last_lang = lang;
	}
	prints(buf);
}

==> UnderB-1.05.tar.gz: UnderB-1.05/c_msg.c <==
#include "c_msg.h"

static char buf[MAX_MSG_LEN+2];
static int last_index = -1;
static int last_lang = -1;

typedef struct {
	char e_msg[MAX_MSG_LEN+1];
	char k_msg[MAX_MSG_LEN+1];
} msg_t;

msg_t msg[N_MSG] = {
	{"--MORE--", "----" },
	{"In progress...", "ѷ~  Ҳ..."},
	{"Done!", " !"},
	{"Cancelled!", "߾!"},
	{"Added.", "߽ϴ."},
	{"Deleting.", "ϴ."},
	{"Deleted.", "."},
	{"Changed.", "ٲϴ."},
	{"Press any key to start.", "غϽð ƹŰ ġø մϴ."},
	{"Done! Press any key.", "ϴ. ƹŰ ġ."},
	{"File uploaded!", "ȭ Ǿϴ!"},
	{"File downloaded", "ȭ ٿε Ǿϴ."},
	{"Sent!", "½ϴ!"},
	{"Edit Talk Override List.", "ũ ܸƮ ."},
	{"Edit Board Manager List.", "  ."},
	{"Sending to:", ":"},
	{"Delete Range:", ":"},
	{"Posting..", " øϴ.."},
	{"FTP Posting (Cntrl-C to cancel)", "FTP  (ּ=Cntrl-C)"},
	{"Posted!", " ÷Ƚϴ!"},
	{"[RETURN to Re: current title]", "[() (Re: )]"},
	{"File edited", " "},
	{"Kicked!", "á!"},
	{"(New Mail)", "(Ծ)"},
	{"[Monitor Mode]     Press CTRL-C or CTRL-D to exit", "[ϳ?] ߴϽ÷ Ʈ-/Ʈ- ġ"},
	{"Enter the letter/number to toggle, RETURN when done", "ٲٰ   ڳ ڸ .   ġ"},
	{"Never logged in", "ѹ   "},
	{"No plan", "ȹ "},
	{"File saved", "ȭ  Ǿ"},
	{"Scanning The Unzapped Boards ...", " 忡  ã Դϴ..."},
	{"Quitting...", "׸ ߴմϴ..."},
	{"* No Board Selected *", "*    *"},

	{"Nothing!", "Գ..ƹ͵ ..."},
	{"Failed.", "߾."},
	{"Must have a name.", "̸ ־."},
	{"Board already exists.", " ѹ ʾ..̹ ־~"},
	{"I don't have that.", " ϱ ׷ ."},
	{"Invalid name", "..װ .."},
	{"Nothing selected.", "  ־ Ұ Ƴ..ϱ.."},
	{"Error connecting!", " !"},
	{"Protocol error; try another?", " . ٽұ?"},
	{"File error!", "ȭ Դϴ!"},
	{"Cannot get account record.", "īƮ    ׿."},
	{"Invalid address!", "ּҺҸ!"},
	{"Zero length file.", "ֺ  峭ġ??"},
	{"Mail could not be delivered to:", " ȵǳ׿."},
	{"Invalid range!", " ȹٷ ־!"},
	{"Permission error!", "۹̼ !"},
	{"Edit failure", " "},
	{"User no longer logged in.", "̹ ."},
	{"User's pager is off", " ׿."},
	{"Refused!", " ߾!"},
	{"User cannot be paged at this time", "   ؿ."},
	{"No answer, Ringing party again", " ׿. ٽ θϴ"},
	{"No longer being paged", "θ  ߳."},
	{"No more memory", "!! ޸ !"},
	{"Terminal type error!", "͹̳ Ÿ !"},
	{"Exec failed!", "ȭ µ  ߾!"},
	{"Unknown error.", ".. !"}
};

int c_msg(int index, int eol)
{
	extern int lang;

	if (index < 0 || index >= N_MSG)
		index = ERR_UNKNOWN;
	if (last_index == -1 || last_index != index ||
		last_lang == -1 || last_lang != lang)
	{
		if (lang)
		{
			if (eol)
				sprintf(buf, "%s\n", msg[index].k_msg);
			else
				strcpy(buf, msg[index].k_msg);
		}
		else
		{
			if (eol)
				sprintf(buf, "%s\n", msg[index].e_msg);
			else
				strcpy(buf, msg[index].e_msg);
		}
		last_index = index;
		last_lang = lang;
	}
	prints(buf);
	return (strlen(buf));
}
